@@ -7,15 +7,43 @@
 # @Date   :  2020-10-29 13:38:36
 # @Description :  Powered by GitOPEN
 
-__version__ = "0.2.2"
+__version__ = "0.2.4"
 
 import json
-import os
 import time
 from pathlib import Path, PosixPath
 from types import FunctionType
 
-from gitopenlib.utils.basics import remove_0_str
+from basics import remove_0_str
+
+
+def get_paths_from_dir(dirs: str or list, types: str or list, recusive: bool = False):
+    """
+    从指定目录下获取所有指定扩展名文件的路径，不递归子文件夹
+
+    Args:
+        dirs(list): 文件夹路径（绝对路径），单个用str表示，多个用list
+        types(types): 指定文件的扩展名，单个用str表示，多个用list
+        recusive(bool): 是否递归子文件，默认为False
+
+    Returns:
+        list: 文件路径字符串列表
+    """
+
+    if isinstance(dirs, str):
+        dirs = [dirs]
+    if isinstance(types, str):
+        types = [types]
+
+    rule = "**/*." if recusive else "*."
+    result = []
+    for d in dirs:
+        path = Path(d).resolve()
+        for t in types:
+            res = path.glob(rule + t)
+            result.extend(list(res))
+
+    return [str(item) for item in result]
 
 
 def file_writer(
